
// MMFClntUtility.h

// Copyright (c) 2005-2009 Nokia Corporation and/or its subsidiary(-ies).
// All rights reserved.
// This component and the accompanying materials are made available
// under the terms of "Eclipse Public License v1.0"
// which accompanies this distribution, and is available
// at the URL "http://www.eclipse.org/legal/epl-v10.html".
//
// Initial Contributors:
// Nokia Corporation - initial contribution.
//
// Contributors:
//
// Description:
//

#ifndef MMFCLNTUTILITY_H
#define MMFCLNTUTILITY_H

#include <e32std.h>

/**
@publishedAll
@released

Place holder for future CustomInterface support
*/

class MMMFClientUtility
	{
private:
	// Future proofing
	IMPORT_C virtual void ReservedVirtual1();
	IMPORT_C virtual void ReservedVirtual2();
	IMPORT_C virtual void ReservedVirtual3();
	IMPORT_C virtual void ReservedVirtual4();
	IMPORT_C virtual void ReservedVirtual5();
	IMPORT_C virtual void ReservedVirtual6();
	};

#endif // MMFCLNTUTILITY_H

