EXPORTS
	?ReservedVirtual1@MMMFClientUtility@@EAEXXZ @ 1 NONAME ; void MMMFClientUtility::ReservedVirtual1(void)
	?ReservedVirtual2@MMMFClientUtility@@EAEXXZ @ 2 NONAME ; void MMMFClientUtility::ReservedVirtual2(void)
	?ReservedVirtual3@MMMFClientUtility@@EAEXXZ @ 3 NONAME ; void MMMFClientUtility::ReservedVirtual3(void)
	?ReservedVirtual4@MMMFClientUtility@@EAEXXZ @ 4 NONAME ; void MMMFClientUtility::ReservedVirtual4(void)
	?ReservedVirtual5@MMMFClientUtility@@EAEXXZ @ 5 NONAME ; void MMMFClientUtility::ReservedVirtual5(void)
	?ReservedVirtual6@MMMFClientUtility@@EAEXXZ @ 6 NONAME ; void MMMFClientUtility::ReservedVirtual6(void)
	??1CMdaServer@@UAE@XZ @ 7 NONAME ; CMdaServer::~CMdaServer(void)
	?AddListenerL@CMdaServer@@QAEXAAVMMdaObjectEventListener@@@Z @ 8 NONAME ; void CMdaServer::AddListenerL(class MMdaObjectEventListener &)
	?Count@TMdaResourceEntryParser@@QBEIW4TType@1@@Z @ 9 NONAME ; unsigned int TMdaResourceEntryParser::Count(enum TMdaResourceEntryParser::TType) const
	?Entry@TMdaResourceEntryParser@@QBE?BVTPtrC8@@W4TType@1@H@Z @ 10 NONAME ; class TPtrC8 const TMdaResourceEntryParser::Entry(enum TMdaResourceEntryParser::TType, int) const
	?NewL@CMdaServer@@SAPAV1@XZ @ 11 NONAME ; class CMdaServer * CMdaServer::NewL(void)
	?RemoveListener@CMdaServer@@QAEXAAVMMdaObjectEventListener@@@Z @ 12 NONAME ; void CMdaServer::RemoveListener(class MMdaObjectEventListener &)
	?Set@TMdaResourceEntryParser@@QAEXABVTDesC8@@@Z @ 13 NONAME ; void TMdaResourceEntryParser::Set(class TDesC8 const &)
